@@ -29,11 +29,11 @@
 using namespace bt;
 
 
-BTDataSource::BTDataSource(const KUrl &srcUrl, QObject *parent)
+BTDataSource::BTDataSource(const QUrl &srcUrl, QObject *parent)
   : TransferDataSource(srcUrl, parent),
     m_offset(0),
     m_bytes(0),
-    m_torrentSource(KUrl())
+    m_torrentSource(QUrl())
 {
     bt::InitLog(KStandardDirs::locateLocal("appdata", "torrentlog.log"));//initialize the torrent-log
 
@@ -42,7 +42,7 @@ BTDataSource::BTDataSource(const KUrl &srcUrl, QObject *parent)
     bt::Uint16 i = 0;
     do
     {
-        kDebug(5001) << "Trying to set port to" << BittorrentSettings::port() + i;
+        qCDebug(KGET_DEBUG) << "Trying to set port to" << BittorrentSettings::port() + i;
         bt::Globals::instance().initServer(BittorrentSettings::port() + i);
         i++;
     }while (!bt::Globals::instance().getServer().isOK() && i < 10);
@@ -81,7 +81,7 @@ void BTDataSource::start()
     if (m_torrentSource.isEmpty())
     {
         Download *download = new Download(m_source, KStandardDirs::locateLocal("appdata", "tmp/") + m_source.fileName());
-        connect(download, SIGNAL(finishedSuccessfully(KUrl,QByteArray)), SLOT(init(KUrl,QByteArray)));
+        connect(download, SIGNAL(finishedSuccessfully(QUrl,QByteArray)), SLOT(init(QUrl,QByteArray)));
     }
     else 
     {
@@ -121,7 +121,7 @@ void BTDataSource::update()
     tc->update();
 }
 
-void BTDataSource::init(const KUrl &torrentSource, const QByteArray &data)
+void BTDataSource::init(const QUrl &torrentSource, const QByteArray &data)
 {
     Q_UNUSED(data)
     m_torrentSource = torrentSource;
@@ -131,7 +131,7 @@ void BTDataSource::init(const KUrl &torrentSource, const QByteArray &data)
     }
     catch (bt::Error &err)
     {
-        kDebug(5001) << err.toString();
+        qCDebug(KGET_DEBUG) << err.toString();
         //m_ready = false;
     }
     start();
@@ -139,7 +139,7 @@ void BTDataSource::init(const KUrl &torrentSource, const QByteArray &data)
 
 void BTDataSource::addSegment(const KIO::fileoffset_t offset, const KIO::fileoffset_t bytes,  int segmentNum)
 {
-    kDebug(5001);
+    qCDebug(KGET_DEBUG);
 
     if (offset < m_offset)
     {
@@ -175,4 +175,4 @@ void BTDataSource::getData(const KIO::fileoffset_t &off, const QByteArray &dataA
         emit finished();
 }
 
-#include "btdatasource.moc"
+
